pub struct Nlab {
pub a1: AnalogOutput,
pub a2: AnalogOutput,
pub p1: PulseOutput,
pub p2: PulseOutput,
pub ch1: AnalogInput,
pub ch2: AnalogInput,
pub ch3: AnalogInput,
pub ch4: AnalogInput,
/* private fields */
}Expand description
Primary interface to the nLab, used to set outputs, trigger sweeps of input data on scope channels, and monitor power state
Fields
a1: AnalogOutputa2: AnalogOutputp1: PulseOutputp2: PulseOutputch1: AnalogInputch2: AnalogInputch3: AnalogInputch4: AnalogInputImplementations
Sourceimpl Nlab
impl Nlab
pub fn power_status(&self) -> Result<PowerStatus, Error>
Sourceimpl Nlab
impl Nlab
pub fn is_connected(&self) -> bool
pub fn close(&mut self)
pub fn fw_version(&self) -> Result<u8, Box<dyn Error>>
👎Deprecated since 1.1.0: Please use
version insteadpub fn version(&self) -> Result<u16, Box<dyn Error>>
pub fn analog_output(&self, channel: usize) -> Option<&AnalogOutput>
pub fn pulse_output(&self, channel: usize) -> Option<&PulseOutput>
pub fn channel(&self, channel: usize) -> Option<&AnalogInput>